# Fast Youtube Search

This is a simple library that allows you to search videos on Youtube.

It is fast because it doesn't use selenium. It scrapes data directly from
the html of the results page. 

For each video it returns the name, id , and the thumbnail's url.